twobody
=======

A Python package for computing orbits and astronomical observables for binary
stars, exoplanets, and other gravitational two-body systems.

.. image:: https://github.com/adrn/TwoBody/workflows/Test%20twobody/badge.svg
    :target: https://github.com/adrn/TwoBody/workflows/Test%20twobody

.. image:: https://readthedocs.org/projects/twobody/badge/?version=latest
    :target: http://twobody.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge


License
-------

This project is Copyright (c) Adrian Price-Whelan and licensed under the terms
of the MIT license. See the ``licenses`` folder for more information.
